/*
 *  libfb - FreeBASIC's runtime library
 *	Copyright (C) 2004-2008 The FreeBASIC development team.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  As a special exception, the copyright holders of this library give
 *  you permission to link this library with independent modules to
 *  produce an executable, regardless of the license terms of these
 *  independent modules, and to copy and distribute the resulting
 *  executable under terms of your choice, provided that you also meet,
 *  for each linked independent module, the terms and conditions of the
 *  license of that module. An independent module is a module which is
 *  not derived from or based on this library. If you modify this library,
 *  you may extend this exception to your version of the library, but
 *  you are not obligated to do so. If you do not wish to do so, delete
 *  this exception statement from your version.
 */

/*
 * file_reset - RESET function
 *
 * chng: oct/2004 written [v1ctor]
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "fb.h"

/*:::::*/
FBCALL void fb_FileReset ( void )
{
	int i;

	if( __fb_ctx.do_file_reset == FALSE )
		return;

	__fb_ctx.do_file_reset = FALSE;

    FB_LOCK();

    for( i = 1; i != (FB_MAX_FILES - FB_RESERVED_FILES); i++ ) 
	{
        FB_FILE *handle = FB_FILE_TO_HANDLE_VALID( i );
        if( handle->hooks != NULL ) 
		{
            DBG_ASSERT(handle->hooks->pfnClose!=NULL);
            handle->hooks->pfnClose( handle );
        }
    }
    
	/* clear all file handles */
    memset( FB_FILE_TO_HANDLE_VALID( 1 ),
            0,
            sizeof(FB_FILE) * (FB_MAX_FILES - FB_RESERVED_FILES) );

    FB_UNLOCK();
}
